@@ -39,5 +39,5 @@ class WebhookResource(Resource):
     def list(self) -> List[Webhook]:
         return super(WebhookResource, self)._list(None)
 
-    def create(self, opts: WebhookCreateOpts, request_opts: Optional[RequestOpts]) -> Webhook:
+    def create(self, opts: WebhookCreateOpts, request_opts: Optional[RequestOpts] = None) -> Webhook:
         return super(WebhookResource, self)._create(opts, request_opts)
